@@ -1,5 +1,5 @@
 
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 __author__ = 'Juan Batiz-Benet <juan@benet.ai>'
 
 __doc__ = '''
@@ -17,10 +17,12 @@ from key import Namespace
 
 import basic
 from basic import Datastore
+from basic import NullDatastore
 from basic import DictDatastore
 from basic import InterfaceMappingDatastore
 
 from basic import ShimDatastore
+from basic import CacheShimDatastore
 from basic import KeyTransformDatastore
 from basic import LowercaseKeyDatastore
 from basic import NamespaceDatastore
