@@ -89,6 +89,29 @@ class Datastore(object):
 
 
 
+class NullDatastore(Datastore):
+  '''Stores nothing, but conforms to the API. Useful to test with.'''
+
+  def get(self, key):
+    '''Return the object named by key or None if it does not exist (None).'''
+    return None
+
+  def put(self, key, value):
+    '''Store the object `value` named by `key` (does nothing).'''
+    pass
+
+  def delete(self, key):
+    '''Remove the object named by `key` (does nothing).'''
+    pass
+
+  def query(self, query):
+    '''Returns an iterable of objects matching criteria in `query` (empty).'''
+    return query([])
+
+
+
+
+
 class DictDatastore(Datastore):
   '''Simple straw-man in-memory datastore backed by nested dicts.'''
 
@@ -337,6 +360,51 @@ class ShimDatastore(Datastore):
 
 
 
+
+class CacheShimDatastore(ShimDatastore):
+  '''Wraps a datastore with a caching shim optimizes some calls.'''
+
+  def __init__(self, *args, **kwargs):
+
+    self.cache_datastore = kwargs.pop('cache')
+
+    if not isinstance(self.cache_datastore, Datastore):
+      errstr = 'datastore must be of type %s. Got %s.'
+      raise TypeError(errstr % (Datastore, self.cache_datastore))
+
+    super(CacheShimDatastore, self).__init__(*args, **kwargs)
+
+  def get(self, key):
+    '''Return the object named by key or None if it does not exist.
+       CacheShimDatastore first checks its ``cache_datastore``.
+    '''
+    value = self.cache_datastore.get(key)
+    return value if value is not None else self.child_datastore.get(key)
+
+  def put(self, key, value):
+    '''Stores the object `value` named by `key`self.
+       Writes to both ``cache_datastore`` and ``child_datastore``.
+    '''
+    self.cache_datastore.put(key, value)
+    self.child_datastore.put(key, value)
+
+  def delete(self, key):
+    '''Removes the object named by `key`.
+       Writes to both ``cache_datastore`` and ``child_datastore``.
+    '''
+    self.cache_datastore.delete(key)
+    self.child_datastore.delete(key)
+
+  def contains(self, key):
+    '''Returns whether the object named by `key` exists.
+       First checks ``cache_datastore``.
+    '''
+    return self.cache_datastore.contains(key) \
+        or self.child_datastore.contains(key)
+
+
+
+
 class KeyTransformDatastore(ShimDatastore):
   '''Represents a simple ShimDatastore that applies a transform on all incoming
      keys. For example:
@@ -493,8 +561,11 @@ class NestedPathDatastore(KeyTransformDatastore):
     2
 
   '''
+
   _default_depth = 3
   _default_length = 2
+  _default_keyfn = lambda key: key.name
+  _default_keyfn = staticmethod(_default_keyfn)
 
   def __init__(self, *args, **kwargs):
     '''Initializes KeyTransformDatastore with keytransform function.
@@ -507,6 +578,7 @@ class NestedPathDatastore(KeyTransformDatastore):
     # assign the nesting variables
     self.nest_depth = kwargs.pop('depth', self._default_depth)
     self.nest_length = kwargs.pop('length', self._default_length)
+    self.nest_keyfn = kwargs.pop('keyfn', self._default_keyfn)
 
     super(NestedPathDatastore, self).__init__(*args, **kwargs)
     self.keytransform = self.nestKey
@@ -518,11 +590,13 @@ class NestedPathDatastore(KeyTransformDatastore):
   def nestKey(self, key):
     '''Returns a nested `key`.'''
 
-    # if depth * length > len(key.name), we need to pad.
-    mult = 1 + int(self.nest_depth * self.nest_length / len(key.name))
+    nest = self.nest_keyfn(key)
 
-    path = key.name * mult
-    pref = Key(self.nestedPath(path, self.nest_depth, self.nest_length))
+    # if depth * length > len(key.name), we need to pad.
+    mult = 1 + int(self.nest_depth * self.nest_length / len(nest))
+    nest = nest * mult
+
+    pref = Key(self.nestedPath(nest, self.nest_depth, self.nest_length))
     return pref.child(key)
 
   @staticmethod
